action

package
v0.0.0-...-503f145 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 9, 2019 License: Unlicense Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Add

func Add(actionJSON string) (err error)

Add accepts a JSON formatted string of details for an action and records it in memory.

func GetStats

func GetStats() (statReport string)

GetStats reports the statistics we can calculate from our accumulated Actions.

Types

type Action

type Action struct {
	Name string `json:"action"`
	Time int    `json:"time"`
}

Action is used to capture the details for a single action.

type Actions

type Actions []*Action

Actions is a collection of Action

Jump to