package
Version:
v0.0.0-...-503f145
Opens a new window with list of versions in this module.
Published: Jun 9, 2019
License: Unlicense
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Add accepts a JSON formatted string of details for an action
and records it in memory.
func GetStats() (statReport string)
GetStats reports the statistics we can calculate from our accumulated Actions.
type Action struct {
Name string `json:"action"`
Time int `json:"time"`
}
Action is used to capture the details for a single action.
Actions is a collection of Action
Source Files
¶
Click to show internal directories.
Click to hide internal directories.